===========
Computation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Expr.abs
    Expr.approx_n_unique
    Expr.arccos
    Expr.arccosh
    Expr.arcsin
    Expr.arcsinh
    Expr.arctan
    Expr.arctanh
    Expr.arg_unique
    Expr.bitwise_count_ones
    Expr.bitwise_count_zeros
    Expr.bitwise_leading_ones
    Expr.bitwise_trailing_ones
    Expr.bitwise_trailing_zeros
    Expr.bitwise_and
    Expr.bitwise_or
    Expr.bitwise_xor
    Expr.cbrt
    Expr.cos
    Expr.cosh
    Expr.cot
    Expr.cum_count
    Expr.cum_max
    Expr.cum_min
    Expr.cum_prod
    Expr.cum_sum
    Expr.cumulative_eval
    Expr.degrees
    Expr.diff
    Expr.dot
    Expr.entropy
    Expr.ewm_mean
    Expr.ewm_mean_by
    Expr.ewm_std
    Expr.ewm_var
    Expr.exp
    Expr.hash
    Expr.hist
    Expr.kurtosis
    Expr.log
    Expr.log10
    Expr.log1p
    Expr.mode
    Expr.n_unique
    Expr.pct_change
    Expr.peak_max
    Expr.peak_min
    Expr.radians
    Expr.rank
    Expr.rolling_map
    Expr.rolling_max
    Expr.rolling_max_by
    Expr.rolling_mean
    Expr.rolling_mean_by
    Expr.rolling_median
    Expr.rolling_median_by
    Expr.rolling_min
    Expr.rolling_min_by
    Expr.rolling_quantile
    Expr.rolling_quantile_by
    Expr.rolling_skew
    Expr.rolling_std
    Expr.rolling_std_by
    Expr.rolling_sum
    Expr.rolling_sum_by
    Expr.rolling_var
    Expr.rolling_var_by
    Expr.search_sorted
    Expr.sign
    Expr.sin
    Expr.sinh
    Expr.skew
    Expr.sqrt
    Expr.tan
    Expr.tanh
    Expr.unique
    Expr.unique_counts
    Expr.value_counts
